---
Summary: Equals filter
Status: Done
---

# Description

We need to be able to filter by cards in `sbl`.

For this card, the user should be able to filter by a field equalling something specific - and only have those matching cards returned.

# Cucumber

**GIVEN** a scrum repository
**WHEN** `sbl --include [FIELD]=[VALUE]` is run
**THEN** then only cards where the FIELD equals the VALUE

**GIVEN** an include statement
**WHEN** `[VALUE]` contains multiple values separated by a comma
**THEN** then cards that match any of the values are included (OR)

**GIVEN** a scrum repository
**WHEN** `sbl` is run with multiple `--include` arguments
**THEN** then cards that match all of the include statements are included

# Clarifications

-   Search is to be case insensitive
-   Search is to trim the strings
-   Include should be able to be specified in the config
